@@ -80,10 +80,6 @@ class Document:
         file = File(self.target)
         return file.format
 
-    @property
-    def project(self):
-        return self.__project
-
     @property
     def input(self):
         return self.__input
@@ -129,15 +125,15 @@ class Document:
 
     @cached_property
     def keywords(self):
-        return ",".join(self.title.split())
+        return ",".join(map(str.lower, self.title.split()))
 
     # Build
 
     def build(self, *, diff=False, print=False):
         self.read()
         self.process()
-        written = self.write(diff=diff, print=print)
-        return written
+        output = self.write(diff=diff, print=print)
+        return output
 
     # Read
 
@@ -162,6 +158,7 @@ class Document:
             self.__config.setdefault(plugin.name, {})
             if not isinstance(self.__config[plugin.name], dict):
                 self.__config[plugin.name] = {"self": self.__config[plugin.name]}
+        for plugin in self.__plugins:
             plugin.process_config(self.__config)
             if self.__config[plugin.name] and plugin.profile:
                 validator = jsonschema.Draft7Validator(plugin.profile)
