@@ -2,6 +2,7 @@ import os
 import inspect
 from jinja2 import Template
 from .exception import LivemarkException
+from .helpers import cached_property
 
 
 class Plugin:
@@ -16,11 +17,13 @@ class Plugin:
 
     """
 
+    property = cached_property
     priority = 0
     profile = {}
 
     def __init__(self, document):
         self.__document = document
+        self.process_plugin()
 
     @property
     def name(self):
@@ -36,6 +39,9 @@ class Plugin:
 
     # Actions
 
+    def process_plugin(self):
+        pass
+
     def process_config(self, config):
         pass
 
