@@ -12,13 +12,12 @@ class PreparePlugin(Plugin):
         },
     }
 
+    # Process
+
     def process_config(self, config):
         self.config.setdefault("commands", self.config.pop("self", []))
 
     def process_document(self, document):
-        if not self.config:
-            return
-
-        # Prepare document
-        for code in self.config["commands"]:
-            subprocess.run(code, shell=True)
+        if self.config:
+            for code in self.config["commands"]:
+                subprocess.run(code, shell=True)
