@@ -1,5 +1,8 @@
 import sys
 import typer
+import atexit
+import tempfile
+from ..server import Server
 from ..document import Document
 from .main import program
 from . import common
@@ -28,13 +31,17 @@ def program_merge(
 
         # Normal mode
         if not live:
-            written = document.build(diff=diff, print=print)
-            if written and diff:
+            output = document.build(diff=diff, print=print)
+            if output and diff:
                 sys.exit(1)
             sys.exit(0)
 
-        # TODO: implement
-        sys.exit(f"Live mode is not implemented: {host}:{port}")
+        # Live mode
+        atexit.register(document.build)
+        with tempfile.NamedTemporaryFile(suffix=".html") as file:
+            mirror = Document(source, target=file.name)
+            server = Server(mirror)
+            server.start(host=host, port=port, file=file.name)
 
     except Exception as exception:
         typer.secho(str(exception), err=True, fg=typer.colors.RED, bold=True)
