@@ -20,12 +20,19 @@ class Server:
     def document(self):
         return self.__document
 
-    def start(self, *, host=settings.DEFAULT_HOST, port=settings.DEFAULT_PORT):
+    def start(
+        self,
+        *,
+        host=settings.DEFAULT_HOST,
+        port=settings.DEFAULT_PORT,
+        file=settings.DEFAULT_FILE,
+    ):
 
         # Create documents
+        # TODO: move to document (pages/subdocuments)?
         self.__document.read()
         documents = [self.__document]
-        if self.__document.format == "html":
+        if self.__document.format == "html" and self.__document.config["pages"]:
             for page in self.__document.config["pages"]["items"]:
                 page_target = page["path"][1:] or "index.html"
                 page_source = str(Path(page_target).with_suffix(".md"))
@@ -40,4 +47,10 @@ class Server:
         # Run server
         for document in documents:
             self.__server.watch(document.source, document.build, delay=1)
-        self.__server.serve(host=host, port=port, root=".", open_url_delay=1)
+        self.__server.serve(
+            host=host,
+            port=port,
+            root=".",
+            open_url_delay=1,
+            default_filename=file,
+        )
